@@ -30,15 +30,20 @@ This module aims to implement the W3C WebDriver specification which is the
 standardised equivalent to the Selenium WebDriver API., which in turn aims
 at remotely controlling web browsers such as Firefox or Chromium.
 
-At the time of this writing, it was only available as a draft document, so
-changes will be expected. Also, only F<geckodriver> did implement it, or
-at least, most of it.
+At the time of this writing, it was so brand new that I ciould only get
+C<geckodriver> (For Firefox) to work, but that is expected to be fioxed
+very soon indeed.
 
 To make most of this module, or, in fact, to make any reasonable use of
-this module, you would need to refer tot he W3C WebDriver document, which
-can be found L<here|https://w3c.github.io/webdriver/>:
+this module, you would need to refer to the W3C WebDriver recommendation,
+which can be found L<here|https://www.w3.org/TR/webdriver1/>:
 
-   https://w3c.github.io/webdriver/
+   https://www.w3.org/TR/webdriver1/
+
+=head2 CONVENTIONS
+
+Unless otherwise stated, all delays and time differences in this module
+are represented as an integer number of milliseconds.
 
 =cut
 
@@ -51,7 +56,7 @@ use JSON::XS ();
 use AnyEvent ();
 use AnyEvent::HTTP ();
 
-our $VERSION = 0.1;
+our $VERSION = 0.2;
 
 our $WEB_ELEMENT_IDENTIFIER = "element-6066-11e4-a52e-4f735466cecf";
 
@@ -136,7 +141,7 @@ sub AUTOLOAD {
    goto &$name;
 }
 
-=head2 CREATING WEBDRIVER OBJECTS
+=head2 WEBDRIVER OBJECTS
 
 =over
 
@@ -198,6 +203,17 @@ sub DESTROY {
       if exists $self->{sid};
 }
 
+=item $al = $wd->actions
+
+Creates an action list associated with this WebDriver. See L<ACTION
+LISTS>, below, for full details.
+
+=cut
+
+sub actions {
+   AnyEvent::WebDriver::Actions->new (wd => $_[0])
+}
+
 =back
 
 =head2 SIMPLIFIED API
@@ -409,8 +425,7 @@ sub get_window_handles_ {
 
 Switch to the given frame identified by C<$frame>, which must be either
 C<undef> to go back to the top-level browsing context, an integer to
-select the nth subframe, or an element object (as e.g. returned by the
-C<element_object> method.
+select the nth subframe, or an element object.
 
 =cut
 
@@ -481,73 +496,57 @@ sub fullscreen_window_ {
 
 =cut
 
-=item $element_id = $wd->find_element ($location_strategy, $selector)
+=item $element = $wd->find_element ($location_strategy, $selector)
 
 Finds the first element specified by the given selector and returns its
-web element ID (the strong, not the object from the protocol). Raises an
-error when no element was found.
+element object. Raises an error when no element was found.
 
    $element = $wd->find_element ("css selector" => "body a");
    $element = $wd->find_element ("link text" => "Click Here For Porn");
    $element = $wd->find_element ("partial link text" => "orn");
    $element = $wd->find_element ("tag name" => "input");
    $element = $wd->find_element ("xpath" => '//input[@type="text"]');
-   => e.g. "decddca8-5986-4e1d-8c93-efe952505a5f"
+   => e.g. { "element-6066-11e4-a52e-4f735466cecf" => "decddca8-5986-4e1d-8c93-efe952505a5f" }
 
-=item $element_ids = $wd->find_elements ($location_strategy, $selector)
+=item $elements = $wd->find_elements ($location_strategy, $selector)
 
-As above, but returns an arrayref of all found element IDs.
+As above, but returns an arrayref of all found element objects.
 
-=item $element_id = $wd->find_element_from_element ($element_id, $location_strategy, $selector)
+=item $element = $wd->find_element_from_element ($element, $location_strategy, $selector)
 
 Like C<find_element>, but looks only inside the specified C<$element>.
 
-=item $element_ids = $wd->find_elements_from_element ($element_id, $location_strategy, $selector)
+=item $elements = $wd->find_elements_from_element ($element, $location_strategy, $selector)
 
 Like C<find_elements>, but looks only inside the specified C<$element>.
 
    my $head = $wd->find_element ("tag name" => "head");
    my $links = $wd->find_elements_from_element ($head, "tag name", "link");
 
-=item $element_id = $wd->get_active_element
+=item $element = $wd->get_active_element
 
 Returns the active element.
 
 =cut
 
 sub find_element_ {
-   my $cb = pop;
-   $_[0]->post_ (element => { using => "$_[1]", value => "$_[2]" }, sub {
-      $cb->($_[0], $_[0] ne "200" ? $_[1] : $_[1]{$WEB_ELEMENT_IDENTIFIER})
-   });
+   $_[0]->post_ (element => { using => "$_[1]", value => "$_[2]" }, $_[3]);
 }
 
 sub find_elements_ {
-   my $cb = pop;
-   $_[0]->post_ (elements => { using => "$_[1]", value => "$_[2]" }, sub {
-      $cb->($_[0], $_[0] ne "200" ? $_[1] : [ map $_->{$WEB_ELEMENT_IDENTIFIER}, @{$_[1]} ]);
-   });
+   $_[0]->post_ (elements => { using => "$_[1]", value => "$_[2]" }, $_[3]);
 }
 
 sub find_element_from_element_ {
-   my $cb = pop;
-   $_[0]->post_ ("element/$_[1]/element" => { using => "$_[2]", value => "$_[3]" }, sub {
-      $cb->($_[0], $_[0] ne "200" ? $_[1] : $_[1]{$WEB_ELEMENT_IDENTIFIER})
-   });
+   $_[0]->post_ ("element/$_[1]/element" => { using => "$_[2]", value => "$_[3]" }, $_[4]);
 }
 
 sub find_elements_from_element_ {
-   my $cb = pop;
-   $_[0]->post_ ("element/$_[1]/elements" => { using => "$_[2]", value => "$_[3]" }, sub {
-      $cb->($_[0], $_[0] ne "200" ? $_[1] : [ map $_->{$WEB_ELEMENT_IDENTIFIER}, @{$_[1]} ]);
-   });
+   $_[0]->post_ ("element/$_[1]/elements" => { using => "$_[2]", value => "$_[3]" }, $_[4]);
 }
 
 sub get_active_element_ {
-   my $cb = pop;
-   $_[0]->get_ ("element/active" => sub {
-      $cb->($_[0], $_[0] ne "200" ? $_[1] : $_[1]{$WEB_ELEMENT_IDENTIFIER})
-   });
+   $_[0]->get_ ("element/active" => $_[1]);
 }
 
 =back
@@ -562,27 +561,27 @@ sub get_active_element_ {
 
 Returns whether the given input or option element is selected or not.
 
-=item $string = $wd->get_element_attribute ($element_id, $name)
+=item $string = $wd->get_element_attribute ($element, $name)
 
 Returns the value of the given attribute.
 
-=item $string = $wd->get_element_property ($element_id, $name)
+=item $string = $wd->get_element_property ($element, $name)
 
 Returns the value of the given property.
 
-=item $string = $wd->get_element_css_value ($element_id, $name)
+=item $string = $wd->get_element_css_value ($element, $name)
 
 Returns the value of the given CSS value.
 
-=item $string = $wd->get_element_text ($element_id)
+=item $string = $wd->get_element_text ($element)
 
 Returns the (rendered) text content of the given element.
 
-=item $string = $wd->get_element_tag_name ($element_id)
+=item $string = $wd->get_element_tag_name ($element)
 
 Returns the tag of the given element.
 
-=item $rect = $wd->get_element_rect ($element_id)
+=item $rect = $wd->get_element_rect ($element)
 
 Returns the element rect(angle) of the given element.
 
@@ -593,35 +592,35 @@ Returns whether the element is enabled or not.
 =cut
 
 sub is_element_selected_ {
-   $_[0]->get_ ("element/$_[1]/selected" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/selected" => $_[2]);
 }
 
 sub get_element_attribute_ {
-   $_[0]->get_ ("element/$_[1]/attribute/$_[2]" => $_[3]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/attribute/$_[2]" => $_[3]);
 }
 
 sub get_element_property_ {
-   $_[0]->get_ ("element/$_[1]/property/$_[2]" => $_[3]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/property/$_[2]" => $_[3]);
 }
 
 sub get_element_css_value_ {
-   $_[0]->get_ ("element/$_[1]/css/$_[2]" => $_[3]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/css/$_[2]" => $_[3]);
 }
 
 sub get_element_text_ {
-   $_[0]->get_ ("element/$_[1]/text" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/text" => $_[2]);
 }
 
 sub get_element_tag_name_ {
-   $_[0]->get_ ("element/$_[1]/name" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/name" => $_[2]);
 }
 
 sub get_element_rect_ {
-   $_[0]->get_ ("element/$_[1]/rect" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/rect" => $_[2]);
 }
 
 sub is_element_enabled_ {
-   $_[0]->get_ ("element/$_[1]/enabled" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/enabled" => $_[2]);
 }
 
 =back
@@ -632,30 +631,30 @@ sub is_element_enabled_ {
 
 =cut
 
-=item $wd->element_click ($element_id)
+=item $wd->element_click ($element)
 
 Clicks the given element.
 
-=item $wd->element_clear ($element_id)
+=item $wd->element_clear ($element)
 
 Clear the contents of the given element.
 
-=item $wd->element_send_keys ($element_id, $text)
+=item $wd->element_send_keys ($element, $text)
 
 Sends the given text as key events to the given element.
 
 =cut
 
 sub element_click_ {
-   $_[0]->post_ ("element/$_[1]/click" => undef, $_[2]);
+   $_[0]->post_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/click" => undef, $_[2]);
 }
 
 sub element_clear_ {
-   $_[0]->post_ ("element/$_[1]/clear" => undef, $_[2]);
+   $_[0]->post_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/clear" => undef, $_[2]);
 }
 
 sub element_send_keys_ {
-   $_[0]->post_ ("element/$_[1]/value" => { text => "$_[2]" }, $_[3]);
+   $_[0]->post_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/value" => { text => "$_[2]" }, $_[3]);
 }
 
 =back
@@ -765,12 +764,13 @@ sub delete_all_cookies_ {
 =item $wd->perform_actions ($actions)
 
 Perform the given actions (an arrayref of action specifications simulating
-user activity). For further details, read the spec.
+user activity, or an C<AnyEvent::WebDriver::Actions> object). For further
+details, read the spec or the section L<ACTION LISTS>, below.
 
-An example to get you started:
+An example to get you started (see the next example for a mostly
+equivalent example using the C<AnyEvent::WebDriver::Actions> helper API):
 
    $wd->navigate_to ("https://duckduckgo.com/html");
-   $wd->set_timeouts ({ implicit => 10000 });
    my $input = $wd->find_element ("css selector", 'input[type="text"]');
    $wd->perform_actions ([
       {
@@ -778,7 +778,7 @@ An example to get you started:
          type => "pointer",
          pointerType => "touch",
          actions => [
-            { type => "pointerMove", duration => 100, origin => $wd->element_object ($input), x => 40, y => 5 },
+            { type => "pointerMove", duration => 100, origin => $input, x => 40, y => 5 },
             { type => "pointerDown", button => 1 },
             { type => "pause", duration => 40 },
             { type => "pointerUp", button => 1 },
@@ -808,6 +808,23 @@ An example to get you started:
       },
    ]);
 
+And here is essentially the same (except for fewer pauses) example as
+above, using the much simpler C<AnyEvent::WebDriver::Actions> API. Note
+that the pointer up and key down event happen concurrently in this
+example:
+
+   $wd->navigate_to ("https://duckduckgo.com/html");
+   my $input = $wd->find_element ("css selector", 'input[type="text"]');
+   $wd->actions
+      ->move ($input, 40, 5, "touch1")
+      ->click;
+      ->key ("a");
+      ->key ("b");
+      ->pause (2000);
+      ->key ("\x{E007}")
+      ->pause (5000);
+      ->perform;
+
 =item $wd->release_actions
 
 Release all keys and pointer buttons currently depressed.
@@ -815,7 +832,13 @@ Release all keys and pointer buttons currently depressed.
 =cut
 
 sub perform_actions_ {
-   $_[0]->post_ (actions => { actions => $_[1] }, $_[2]);
+   if (UNIVERSAL::isa $_[1], AnyEvent::WebDriver::Actions::) {
+      my ($actions, $duration) = $_[1]->compile;
+      local $_[0]{timeout} = $_[0]{timeout} + $duration * 1e-3;
+      $_[0]->post_ (actions => { actions => $actions }, $_[2]);
+   } else {
+      $_[0]->post_ (actions => { actions => $_[1] }, $_[2]);
+   }
 }
 
 sub release_actions_ {
@@ -877,7 +900,7 @@ sub send_alert_text_ {
 
 Create a screenshot, returning it as a PNG image in a C<data:> URL.
 
-=item $wd->take_element_screenshot ($element_id)
+=item $wd->take_element_screenshot ($element)
 
 Accept a simple dialog, if present.
 
@@ -888,29 +911,369 @@ sub take_screenshot_ {
 }
 
 sub take_element_screenshot_ {
-   $_[0]->get_ ("element/$_[1]/screenshot" => $_[2]);
+   $_[0]->get_ ("element/$_[1]{$WEB_ELEMENT_IDENTIFIER}/screenshot" => $_[2]);
 }
 
 =back
 
-=head2 HELPER METHODS
+=head2 ACTION LISTS
 
-=over
+Action lists can be quite complicated. Or at least it took a while for
+me to twist my head around them. Basically, an action list consists of a
+number of sources representing devices (such as a finger, a mouse, a pen
+or a keyboard) and a list of actions for each source.
+
+An action can be a key press, a pointer move or a pause (time
+delay). Actions from different sources can happen "at the same time",
+while actions from a single source are executed in order.
+
+While you can provide an action list manually, it is (hopefully) less
+cumbersome to use the API described in this section to create them.
+
+The basic process of creating and performing actions is to create a new
+action list, adding action sources, followed by adding actions. Finally
+you would C<perform> those actions on the WebDriver.
+
+Virtual time progresses as long as you add actions to the same event
+source. Adding events to different sources are considered to happen
+concurrently. If you want to force time to progress, you can do this using
+a call to C<< ->pause (0) >>.
+
+Most methods here are designed to chain, i.e. they return the web actions
+object, to simplify multiple calls.
+
+For example, to simulate a mouse click to an input element, followed by
+entering some text and pressing enter, you can use this:
+
+   $wd->actions
+      ->click (1, 100)
+      ->type ("some text")
+      ->key ("Enter")
+      ->perform;
+
+By default, keyboard and mouse input sources are provided. You can create
+your own sources and use them when adding events. The above example could
+be more verbosely written like this:
+
+   $wd->actions
+      ->click (1, 100, "mouse")
+      ->type ("some text")
+      ->key ("Enter")
+      ->perform;
+
+   
+
+#TODO verboser example
+
+When you specify the event source expliticly it will switch the current
+"focus" for this class of device (all keyboards are in one class, all
+pointer-like devices such as mice/fingers/pens are in one class), so you
+don't have to specify the source for subsequent actions.
+
+When you use the sources C<keyboard>, C<mouse>, C<touch1>..C<touch3>,
+C<pen> without defining them, then a suitable default source will be
+created for them.
+
+=over 4
 
 =cut
 
-=item $object = AnyEvent::WebDriver->element_object ($element_id)
+package AnyEvent::WebDriver::Actions;
 
-=item $object = $wd->element_object ($element_id)
+=item $al = new AnyEvent::WebDriver::Actions
 
-Encoding element IDs in data structures is done by representing them as an
-object with a special key and the element ID as value. This helper method
-does this for you.
+Create a new empty action list object. More often you would use the C<<
+$sel->action_list >> method to create one that is already associated with
+a given web driver.
 
 =cut
 
-sub element_object {
-   +{ $WEB_ELEMENT_IDENTIFIER => $_[1] }
+sub new {
+   my ($class, %kv) = @_;
+
+   $kv{last_kbd} = "keyboard";
+   $kv{last_ptr} = "mouse";
+
+   bless \%kv, $class
+}
+
+=item $al = $al->source ($id, $type, key => value...)
+
+The first time you call this with a givne ID, this defines the event
+source using the extra parameters. Subsequent calls merely switch the
+current source for its event class.
+
+It's not an error to define built-in sources (such as C<keyboard> or
+C<touch1>) differently then the defaults.
+
+Example: define a new touch device called C<fatfinger>.
+
+   $al->source (fatfinger => "pointer", pointerType => "touch");
+
+Example: switchdefine a new touch device called C<fatfinger>.
+
+   $al->source (fatfinger => "pointer", pointerType => "touch");
+
+=cut
+
+sub _default_source {
+   my ($source) = @_;
+
+      $source eq "keyboard" ? { actions => [], id => $source, type => "key" }
+    : $source eq "mouse"    ? { actions => [], id => $source, type => "pointer", pointerType => "mouse" }
+    : $source eq "touch"    ? { actions => [], id => $source, type => "pointer", pointerType => "touch" }
+    : $source eq "pen"      ? { actions => [], id => $source, type => "pointer", pointerType => "pen" }
+    : Carp::croak "AnyEvent::WebDriver::Actions: event source '$source' not defined"
+}
+
+my %source_class = (
+   key     => "kbd",
+   pointer => "ptr",
+);
+
+sub source {
+   my ($self, $id, $type, %kv) = @_;
+
+   if (defined $type) {
+      !exists $self->{source}{$id}
+         or Carp::croak "AnyEvent::WebDriver::Actions: source '$id' already defined";
+
+      $kv{id}      = $id;
+      $kv{type}    = $type;
+      $kv{actions} = [];
+
+      $self->{source}{$id} = \%kv;
+   }
+
+   my $source = $self->{source}{$id} ||= _default_source $id;
+
+   my $last = $source_class{$source->{type}} // "xxx";
+
+   $self->{"last_$last"} = $id;
+
+   $self
+}
+
+sub _add {
+   my ($self, $source, $sourcetype, $type, %kv) = @_;
+
+   my $last = \$self->{"last_$sourcetype"};
+
+   $source
+      ? ($$last = $source)
+      : ($source = $$last);
+
+   my $source = $self->{source}{$source} ||= _default_source $source;
+
+   my $al = $source->{actions};
+
+   push @$al, { type => "pause" }
+      while @$al < $self->{tick} - 1;
+
+   $kv{type} = $type;
+
+   push @{ $source->{actions} }, \%kv;
+
+   $self->{tick_duration} = $kv{duration}
+      if $kv{duration} > $self->{tick_duration};
+
+   if ($self->{tick} != @$al) {
+      $self->{tick} = @$al;
+      $self->{duration} += delete $self->{tick_duration};
+   }
+
+   $self
+}
+
+=item $al = $al->pause ($duration)
+
+Creates a pause with the given duration. Makes sure that time progresses
+in any case, even when C<$duration> is C<0>.
+
+=cut
+
+sub pause {
+   my ($self, $duration) = @_;
+
+   $self->{tick_duration} = $duration
+      if $duration > $self->{tick_duration};
+
+   $self->{duration} += delete $self->{tick_duration};
+
+   # find the source with the longest list
+
+   for my $source (values %{ $self->{source} }) {
+      if (@{ $source->{actions} } == $self->{tick}) {
+         # this source is one of the longest
+
+         # create a pause event only if $duration is non-zero...
+         push @{ $source->{actions} }, { type => "pause", duration => $duration*1 }
+            if $duration;
+
+         # ... but advance time in any case
+         ++$self->{tick};
+
+         return $self;
+      }
+   }
+
+   # no event sources are longest. so advance time in any case
+   ++$self->{tick};
+
+   Carp::croak "AnyEvent::WebDriver::Actions: multiple pause calls in a row not (yet) supported"
+      if $duration;
+
+   $self
+}
+
+=item $al = $al->pointer_down ($button, $source)
+
+=item $al = $al->pointer_up ($button, $source)
+
+Press or release the given button. C<$button> defaults to C<1>.
+
+=item $al = $al->click ($button, $source)
+
+Convenience function that creates a button press and release action
+without any delay between them. C<$button> defaults to C<1>.
+
+=item $al = $al->doubleclick ($button, $source)
+
+Convenience function that creates two button press and release action
+pairs in a row, with no unnecessary delay between them. C<$button>
+defaults to C<1>.
+
+=cut
+
+sub pointer_down {
+   my ($self, $button, $source) = @_;
+
+   $self->_add ($source, ptr => pointerDown => button => ($button // 1)*1)
+}
+
+sub pointer_up {
+   my ($self, $button, $source) = @_;
+
+   $self->_add ($source, ptr => pointerUp => button => ($button // 1)*1)
+}
+
+sub click {
+   my ($self, $button, $source) = @_;
+
+   $self
+      ->pointer_down ($button, $source)
+      ->pointer_up   ($button)
+}
+
+sub doubleclick {
+   my ($self, $button, $source) = @_;
+
+   $self
+      ->click ($button, $source)
+      ->click ($button)
+}
+
+=item $al = $al->move ($button, $origin, $x, $y, $duration, $source)
+
+Moves a pointer to the given position, relative to origin (either
+"viewport", "pointer" or an element object.
+
+=cut
+
+sub move {
+   my ($self, $origin, $x, $y, $duration, $source) = @_;
+
+   $self->_add ($source, ptr => pointerMove =>
+                origin => $origin, x => $x*1, y => $y*1, duration => $duration*1)
+}
+
+=item $al = $al->keyDown ($key, $source)
+
+=item $al = $al->keyUp ($key, $source)
+
+Press or release the given key.
+
+=cut
+
+sub key_down {
+   my ($self, $key, $source) = @_;
+
+   $self->_add ($source, kbd => keyDown => value => $key)
+}
+
+sub key_up {
+   my ($self, $key, $source) = @_;
+
+   $self->_add ($source, kbd => keyUp => value => $key)
+}
+
+sub key {
+   my ($self, $key, $source) = @_;
+
+   $self
+      ->key_down ($key, $source)
+      ->key_up   ($key)
+}
+
+=item $al->perform ($wd)
+
+Finaluses and compiles the list, if not done yet, and calls C<<
+$wd->perform >> with it.
+
+If C<$wd> is undef, and the action list was created using the C<<
+$wd->actions >> method, then perform it against that WebDriver object.
+
+There is no underscore variant - call the C<perform_actions_> method with
+the action object instead.
+
+=item $al->perform_release ($wd)
+
+Exactly like C<perform>, but additionally call C<release_actions>
+afterwards.
+
+=cut
+
+sub perform {
+   my ($self, $wd) = @_;
+
+   ($wd //= $self->{wd})->perform_actions ($self)
+}
+
+sub perform_release {
+   my ($self, $wd) = @_;
+
+   ($wd //= $self->{wd})->perform_actions ($self);
+   $wd->release_actions;
+}
+
+=item ($actions, $duration) = $al->compile
+
+Finalises and compiles the list, if not done yet, and returns an actions
+object suitable for calls to C<< $wd->perform_actions >>. When called in
+list context, additionally returns the total duration of the action list.
+
+Since building large action lists can take nontrivial amounts of time,
+it can make sense to build an action list only once and then perform it
+multiple times.
+
+Actions must not be added after compiling a list.
+
+=cut
+
+sub compile {
+   my ($self) = @_;
+
+   $self->{duration} += delete $self->{tick_duration};
+
+   delete $self->{tick};
+   delete $self->{last_kbd};
+   delete $self->{last_ptr};
+
+   $self->{actions} ||= [values %{ delete $self->{source} }];
+
+   wantarray
+      ? ($self->{actions}, $self->{duration})
+      : $self->{actions}
 }
 
 =back
@@ -1019,14 +1382,9 @@ Example: implement C<execute_script>, which needs some parameters:
 
    $results = $wd->post ("execute/sync" => { script => "$javascript", args => [] });
 
-Example: call C<find_elements> to find all C<IMG> elements, stripping the
-returned element objects to only return the element ID strings:
+Example: call C<find_elements> to find all C<IMG> elements:
 
-   my $elems = $wd->post (elements => { using => "css selector", value => "img" });
-
-   # yes, the W3C found an interesting way around the typelessness of JSON
-   $_ = $_->{"element-6066-11e4-a52e-4f735466cecf"}
-      for @$elems;
+   $elems = $wd->post (elements => { using => "css selector", value => "img" });
 
 =cut
 
